summaryrefslogtreecommitdiff
path: root/resources/jquery.ui/jquery.ui.slider.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery.ui/jquery.ui.slider.js')
-rw-r--r--resources/jquery.ui/jquery.ui.slider.js24
1 files changed, 12 insertions, 12 deletions
diff --git a/resources/jquery.ui/jquery.ui.slider.js b/resources/jquery.ui/jquery.ui.slider.js
index 81d854b5..f02a922f 100644
--- a/resources/jquery.ui/jquery.ui.slider.js
+++ b/resources/jquery.ui/jquery.ui.slider.js
@@ -1,9 +1,9 @@
/*
* jQuery UI Slider 1.8.2
*
- * Copyright (c) 2010 AUTHORS.txt (http://jqueryui.com/about)
- * Dual licensed under the MIT (MIT-LICENSE.txt)
- * and GPL (GPL-LICENSE.txt) licenses.
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Dual licensed under the MIT or GPL Version 2 licenses.
+ * http://jquery.org/license
*
* http://docs.jquery.com/UI/Slider
*
@@ -12,8 +12,7 @@
* jquery.ui.mouse.js
* jquery.ui.widget.js
*/
-
-(function( $ ) {
+(function( $, undefined ) {
// number of pages in a slider
// (how many times can you page up/down to go through the whole range)
@@ -310,8 +309,9 @@ $.widget( "ui.slider", $.ui.mouse, {
( parseInt( closestHandle.css("marginTop"), 10 ) || 0)
};
- normValue = this._normValueFromMouse( position );
- this._slide( event, index, normValue );
+ if ( !this.handles.hasClass( "ui-state-hover" ) ) {
+ this._slide( event, index, normValue );
+ }
this._animateOff = true;
return true;
},
@@ -585,14 +585,14 @@ $.widget( "ui.slider", $.ui.mouse, {
// returns the step-aligned value that val is closest to, between (inclusive) min and max
_trimAlignValue: function( val ) {
- if ( val < this._valueMin() ) {
+ if ( val <= this._valueMin() ) {
return this._valueMin();
}
- if ( val > this._valueMax() ) {
+ if ( val >= this._valueMax() ) {
return this._valueMax();
}
var step = ( this.options.step > 0 ) ? this.options.step : 1,
- valModStep = val % step,
+ valModStep = (val - this._valueMin()) % step;
alignValue = val - valModStep;
if ( Math.abs(valModStep) * 2 >= step ) {
@@ -676,7 +676,7 @@ $.widget( "ui.slider", $.ui.mouse, {
});
$.extend( $.ui.slider, {
- version: "1.8.2"
+ version: "1.8.11"
});
}(jQuery));
@@ -1,9 +1,9 @@
/*
- * jQuery UI Slider 1.8.2
+ * jQuery UI Slider 1.8.11
*